/*
 * This source code (.java) file is Copyright  2000 Artima Software, Inc. All rights reserved. 
 * This file accompanies the Jini Place Service Draft Specification, written by Bill
 * Venners and published on the World Wide Web at:
 * 
 *     http://www.artima.com/jini/cyberspace/DraftSpec.html,
 *
 * This source file may not be copied, modified, or redistributed EXCEPT as allowed
 * by the following statements: From August 11, 2000 through December 31, 2000, you may
 * copy and/or modify these files to test and experiment with the Place API,
 * described in the Jini Place Service Draft Specification. Any bug fixes must be given
 * back to Artima Software, Inc. You may not redistribute this file or any binary (such
 * as .class) files generated from this file. You may not distribute modified versions
 * this files or any binary (such as .class) files generated from modified versions of
 * this file. You may not remove this copyright notice. You may not use this file in
 * printed media without the express permission of Bill Venners. And if that weren't
 * enough, you must destroy all copies of this file, and any binary (such as
 * .class) files generated from this file, by December 31, 2000.
 *
 * ARTIMA SOFTWARE, INC. MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THIS SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
 * BILL VENNERS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY A LICENSEE AS A RESULT
 * OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
*/
package com.artima.cyberspace.ui;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Map;
import com.artima.cyberspace.*;
import net.artima.place.*;
import java.util.Locale;
import java.net.URL;
import java.util.Collection;
import java.util.Iterator;
import java.rmi.RemoteException;

public class IconPlaceJFrame extends JFrame {

    private Place place;

    private static class ClickListener extends MouseAdapter {

        Link link;

        public ClickListener(Link link) {
            this.link = link;
        }

        public void mouseClicked(MouseEvent e) {

            try {
                link.activate();
            }
            catch (LinkActivationException lae) {
                lae.printStackTrace(System.out);
            }
            catch (RemoteException re) {
                re.printStackTrace(System.out);
            }
        }
    }

    public IconPlaceJFrame(String title, Place place, Object[] keys) {

        super(title);
        this.place = place;

        JPanel bigIconsPanel = new JPanel();
        bigIconsPanel.setLayout(new FlowLayout(FlowLayout.LEFT, 0, 0));
        bigIconsPanel.setBackground(Color.white);

        LinkMap linkMap = place.getLinkMap();

        Locale locale = Locale.getDefault();

        // Put up all the icons
        for (int i = 0; i < keys.length; ++i) {

            Link link = null;
            try {
                link = (Link) linkMap.get(keys[i]);
            }
            catch (RemoteException e) {
                e.printStackTrace();
                continue;
            }

            ResourceInfo info = link.getResourceInfo();

            String name = info.getName();
            String description = info.getDescription();

            URL iconURL = info.getIconImageFile(ResourceInfo.ICON_COLOR_32x32);
            ImageIcon iconImage = new ImageIcon(iconURL);
	    Image image = iconImage.getImage();
            BigIcon bigIcon = new BigIcon(name, description, image);

            bigIconsPanel.add(bigIcon);

            bigIcon.addMouseListener(new ClickListener(link));
        }

        getContentPane().setLayout(new BorderLayout());
        getContentPane().add("Center", bigIconsPanel);
    }
}
